@@ -125,24 +125,24 @@ static ECalBackendClass *parent_class = NULL;
 static guint get_cache_refresh_interval (ECalBackendGroupwise *cbgw);
 
 EGwConnection *
-e_cal_backend_groupwise_get_connection (ECalBackendGroupwise *cbgw) {
-
+e_cal_backend_groupwise_get_connection (ECalBackendGroupwise *cbgw)
+{
 	g_return_val_if_fail (E_IS_CAL_BACKEND_GROUPWISE (cbgw), NULL);
 
 	return cbgw->priv->cnc;
 }
 
 GHashTable *
-e_cal_backend_groupwise_get_categories_by_id (ECalBackendGroupwise *cbgw) {
-
+e_cal_backend_groupwise_get_categories_by_id (ECalBackendGroupwise *cbgw)
+{
 	g_return_val_if_fail (E_IS_CAL_BACKEND_GROUPWISE (cbgw), NULL);
 
 	return cbgw->priv->categories_by_id;
 }
 
 GHashTable *
-e_cal_backend_groupwise_get_categories_by_name (ECalBackendGroupwise *cbgw) {
-
+e_cal_backend_groupwise_get_categories_by_name (ECalBackendGroupwise *cbgw)
+{
 	g_return_val_if_fail (E_IS_CAL_BACKEND_GROUPWISE (cbgw), NULL);
 
 	return cbgw->priv->categories_by_name;
@@ -185,7 +185,8 @@ get_element_type (icalcomponent_kind kind)
 
 /* TODO Do not replicate this in every backend */
 static icaltimezone *
-resolve_tzid (const gchar *tzid, gpointer user_data)
+resolve_tzid (const gchar *tzid,
+              gpointer user_data)
 {
 	icaltimezone *zone;
 
@@ -201,7 +202,7 @@ resolve_tzid (const gchar *tzid, gpointer user_data)
 
 static void
 put_component_to_store (ECalBackendGroupwise *cbgw,
-			ECalComponent *comp)
+                        ECalComponent *comp)
 {
 	time_t time_start, time_end;
 	ECalBackendGroupwisePrivate *priv;
@@ -222,7 +223,8 @@ struct progressData
 };
 
 static gboolean
-update_progress_cb (EDataCalView *view, gpointer user_data)
+update_progress_cb (EDataCalView *view,
+                    gpointer user_data)
 {
 	struct progressData *pd = user_data;
 
@@ -239,7 +241,9 @@ update_progress_cb (EDataCalView *view, gpointer user_data)
 }
 
 static void
-notify_view_progress (ECalBackend *backend, gint percent, const gchar *message)
+notify_view_progress (ECalBackend *backend,
+                      gint percent,
+                      const gchar *message)
 {
 	struct progressData pd;
 
@@ -266,7 +270,7 @@ populate_cache (ECalBackendGroupwise *cbgw)
 	const gchar *position = E_GW_CURSOR_POSITION_END;
 	icalcomponent_kind kind;
 	const gchar *type;
-	EGwFilter* filter[3];
+	EGwFilter * filter[3];
 	gchar l_str[26];
 	gchar h_str[26];
 	icaltimetype temp;
@@ -287,7 +291,7 @@ populate_cache (ECalBackendGroupwise *cbgw)
 	l_time = icaltime_as_timet_with_zone (temp, icaltimezone_get_utc_timezone ());
 	gmtime_r (&l_time, &tm);
 	strftime (l_str, 26, "%Y-%m-%dT%H:%M:%SZ", &tm);
-	temp.day += (2*i);
+	temp.day += (2 * i);
 	icaltime_normalize (temp);
 	h_time = icaltime_as_timet_with_zone (temp, icaltimezone_get_utc_timezone ());
 	gmtime_r (&h_time, &tm);
@@ -341,7 +345,7 @@ populate_cache (ECalBackendGroupwise *cbgw)
 
 				/* Show the progress information */
 				num++;
-				percent = ((gfloat) num/total) * 100;
+				percent = ((gfloat) num / total) * 100;
 
 				/* FIXME The total obtained from the server is wrong. Sometimes the num can
 				be greater than the total. The following makes sure that the percentage is not >= 100 */
@@ -391,7 +395,8 @@ typedef struct
 } CompareIdData;
 
 static gint
-compare_ids (gconstpointer a, gconstpointer b)
+compare_ids (gconstpointer a,
+             gconstpointer b)
 {
 	ECalComponentId *cache_id = (ECalComponentId *) a;
 	CompareIdData *data = (CompareIdData *) b;
@@ -554,7 +559,7 @@ get_deltas (gpointer handle)
 	e_cal_backend_store_thaw_changes (store);
 
 	/* Server utc time is the time when we lasted updated changes from server. local_utc_time is the system utc time. As
-	   there is no way to get the server time on demand, we use the store system utc time to calculate server's time */
+	 * there is no way to get the server time on demand, we use the store system utc time to calculate server's time */
 	local_utc_time = e_cal_backend_store_get_key_value (store, LOCAL_UTC_TIME);
 	current = icaltime_current_time_with_zone (icaltimezone_get_utc_timezone ());
 
@@ -762,7 +767,7 @@ get_cache_refresh_interval (ECalBackendGroupwise *cbgw)
 
 	if (time_interval_string) {
 		time_interval = g_ascii_strtod (time_interval_string, NULL);
-		time_interval *= (60*1000);
+		time_interval *= (60 * 1000);
 	}
 
 	g_free (temp);
@@ -910,7 +915,7 @@ cache_init (ECalBackendGroupwise *cbgw)
 		hold->opts = opts;
 
 		/* We now sync the sendoptions into e-source using the GLIB main loop. Doing this operation
-		    in a thread causes crashes. */
+		 *  in a thread causes crashes. */
 		priv->sendoptions_sync_timeout = g_idle_add ((GSourceFunc ) e_cal_backend_groupwise_store_settings, hold);
 	} else
 		g_warning (G_STRLOC ": Could not get the settings from the server");
@@ -957,7 +962,8 @@ cache_init (ECalBackendGroupwise *cbgw)
 }
 
 static gboolean
-set_container_id_with_count (ECalBackendGroupwise *cbgw, GError **perror)
+set_container_id_with_count (ECalBackendGroupwise *cbgw,
+                             GError **perror)
 {
 	ECalBackendGroupwisePrivate *priv;
 	GList *container_list = NULL, *l;
@@ -1013,7 +1019,8 @@ set_container_id_with_count (ECalBackendGroupwise *cbgw, GError **perror)
 }
 
 static void
-connect_to_server (ECalBackendGroupwise *cbgw, GError **perror)
+connect_to_server (ECalBackendGroupwise *cbgw,
+                   GError **perror)
 {
 	gchar *real_uri;
 	ECalBackendGroupwisePrivate *priv;
@@ -1247,7 +1254,12 @@ e_cal_backend_groupwise_finalize (GObject *object)
 /* Calendar backend methods */
 
 static gboolean
-e_cal_backend_groupwise_get_backend_property (ECalBackendSync *backend, EDataCal *cal, GCancellable *cancellable, const gchar *prop_name, gchar **prop_value, GError **perror)
+e_cal_backend_groupwise_get_backend_property (ECalBackendSync *backend,
+                                              EDataCal *cal,
+                                              GCancellable *cancellable,
+                                              const gchar *prop_name,
+                                              gchar **prop_value,
+                                              GError **perror)
 {
 	gboolean processed = TRUE;
 
@@ -1318,7 +1330,8 @@ e_cal_backend_groupwise_get_backend_property (ECalBackendSync *backend, EDataCal
 }
 
 static void
-in_offline (ECalBackendGroupwise *cbgw) {
+in_offline (ECalBackendGroupwise *cbgw)
+{
 	ECalBackendGroupwisePrivate *priv;
 
 	priv= cbgw->priv;
@@ -1348,7 +1361,11 @@ in_offline (ECalBackendGroupwise *cbgw) {
 
 /* Open handler for the file backend */
 static void
-e_cal_backend_groupwise_open (ECalBackendSync *backend, EDataCal *cal, GCancellable *cancellable, gboolean only_if_exists, GError **perror)
+e_cal_backend_groupwise_open (ECalBackendSync *backend,
+                              EDataCal *cal,
+                              GCancellable *cancellable,
+                              gboolean only_if_exists,
+                              GError **perror)
 {
 	ECalBackendGroupwise *cbgw;
 	ECalBackendGroupwisePrivate *priv;
@@ -1416,7 +1433,10 @@ e_cal_backend_groupwise_open (ECalBackendSync *backend, EDataCal *cal, GCancella
 }
 
 static void
-e_cal_backend_groupwise_authenticate_user (ECalBackendSync *backend, GCancellable *cancellable, ECredentials *credentials, GError **error)
+e_cal_backend_groupwise_authenticate_user (ECalBackendSync *backend,
+                                           GCancellable *cancellable,
+                                           ECredentials *credentials,
+                                           GError **error)
 {
 	ECalBackendGroupwise        *cbgw;
 	ECalBackendGroupwisePrivate *priv;
@@ -1443,7 +1463,10 @@ e_cal_backend_groupwise_authenticate_user (ECalBackendSync *backend, GCancellabl
 }
 
 static void
-e_cal_backend_groupwise_remove (ECalBackendSync *backend, EDataCal *cal, GCancellable *cancellable, GError **perror)
+e_cal_backend_groupwise_remove (ECalBackendSync *backend,
+                                EDataCal *cal,
+                                GCancellable *cancellable,
+                                GError **perror)
 {
 	ECalBackendGroupwise *cbgw;
 	ECalBackendGroupwisePrivate *priv;
@@ -1462,7 +1485,8 @@ e_cal_backend_groupwise_remove (ECalBackendSync *backend, EDataCal *cal, GCancel
 
 /* Set_mode handler for the file backend */
 static void
-e_cal_backend_groupwise_set_online (ECalBackend *backend, gboolean is_online)
+e_cal_backend_groupwise_set_online (ECalBackend *backend,
+                                    gboolean is_online)
 {
 	ECalBackendGroupwise *cbgw;
 	ECalBackendGroupwisePrivate *priv;
@@ -1497,7 +1521,13 @@ e_cal_backend_groupwise_set_online (ECalBackend *backend, gboolean is_online)
 
 /* Get_object_component handler for the groupwise backend */
 static void
-e_cal_backend_groupwise_get_object (ECalBackendSync *backend, EDataCal *cal, GCancellable *cancellable, const gchar *uid, const gchar *rid, gchar **object, GError **error)
+e_cal_backend_groupwise_get_object (ECalBackendSync *backend,
+                                    EDataCal *cal,
+                                    GCancellable *cancellable,
+                                    const gchar *uid,
+                                    const gchar *rid,
+                                    gchar **object,
+                                    GError **error)
 {
 	ECalComponent *comp;
 	ECalBackendGroupwisePrivate *priv;
@@ -1534,7 +1564,11 @@ e_cal_backend_groupwise_get_object (ECalBackendSync *backend, EDataCal *cal, GCa
 
 /* Add_timezone handler for the groupwise backend */
 static void
-e_cal_backend_groupwise_add_timezone (ECalBackendSync *backend, EDataCal *cal, GCancellable *cancellable, const gchar *tzobj, GError **error)
+e_cal_backend_groupwise_add_timezone (ECalBackendSync *backend,
+                                      EDataCal *cal,
+                                      GCancellable *cancellable,
+                                      const gchar *tzobj,
+                                      GError **error)
 {
 	icalcomponent *tz_comp;
 	ECalBackendGroupwise *cbgw;
@@ -1569,14 +1603,25 @@ e_cal_backend_groupwise_add_timezone (ECalBackendSync *backend, EDataCal *cal, G
 
 /* Gets the list of attachments */
 static void
-e_cal_backend_groupwise_get_attachment_uris (ECalBackendSync *backend, EDataCal *cal, GCancellable *cancellable, const gchar *uid, const gchar *rid, GSList **list, GError **perror)
+e_cal_backend_groupwise_get_attachment_uris (ECalBackendSync *backend,
+                                             EDataCal *cal,
+                                             GCancellable *cancellable,
+                                             const gchar *uid,
+                                             const gchar *rid,
+                                             GSList **list,
+                                             GError **perror)
 {
 	/* TODO implement the function */
 }
 
 /* Get_objects_in_range handler for the groupwise backend */
 static void
-e_cal_backend_groupwise_get_object_list (ECalBackendSync *backend, EDataCal *cal, GCancellable *cancellable, const gchar *sexp, GSList **objects, GError **perror)
+e_cal_backend_groupwise_get_object_list (ECalBackendSync *backend,
+                                         EDataCal *cal,
+                                         GCancellable *cancellable,
+                                         const gchar *sexp,
+                                         GSList **objects,
+                                         GError **perror)
 {
 	ECalBackendGroupwise *cbgw;
 	ECalBackendGroupwisePrivate *priv;
@@ -1626,7 +1671,8 @@ e_cal_backend_groupwise_get_object_list (ECalBackendSync *backend, EDataCal *cal
 
 /* get_query handler for the groupwise backend */
 static void
-e_cal_backend_groupwise_start_view (ECalBackend *backend, EDataCalView *query)
+e_cal_backend_groupwise_start_view (ECalBackend *backend,
+                                    EDataCalView *query)
 {
 	GSList *objects = NULL;
 	GError *err = NULL;
@@ -1653,8 +1699,14 @@ e_cal_backend_groupwise_start_view (ECalBackend *backend, EDataCalView *query)
 
 /* Get_free_busy handler for the file backend */
 static void
-e_cal_backend_groupwise_get_free_busy (ECalBackendSync *backend, EDataCal *cal, GCancellable *cancellable, const GSList *users,
-				       time_t start, time_t end, GSList **freebusy, GError **perror)
+e_cal_backend_groupwise_get_free_busy (ECalBackendSync *backend,
+                                       EDataCal *cal,
+                                       GCancellable *cancellable,
+                                       const GSList *users,
+                                       time_t start,
+                                       time_t end,
+                                       GSList **freebusy,
+                                       GError **perror)
 {
 	EGwConnectionStatus status;
 	ECalBackendGroupwise *cbgw;
@@ -1677,7 +1729,8 @@ e_cal_backend_groupwise_get_free_busy (ECalBackendSync *backend, EDataCal *cal,
 }
 
 static icaltimezone *
-e_cal_backend_groupwise_internal_get_timezone (ECalBackend *backend, const gchar *tzid)
+e_cal_backend_groupwise_internal_get_timezone (ECalBackend *backend,
+                                               const gchar *tzid)
 {
 	icaltimezone *zone = NULL;
 	ECalBackendGroupwise *cbgw;
@@ -1696,7 +1749,10 @@ e_cal_backend_groupwise_internal_get_timezone (ECalBackend *backend, const gchar
 }
 
 static EGwConnectionStatus
-update_from_server (ECalBackendGroupwise *cbgw, GSList *uid_list, gchar **calobj, ECalComponent *comp)
+update_from_server (ECalBackendGroupwise *cbgw,
+                    GSList *uid_list,
+                    gchar **calobj,
+                    ECalComponent *comp)
 {
 	EGwConnectionStatus stat;
 	ECalBackendGroupwisePrivate *priv;
@@ -1724,7 +1780,7 @@ update_from_server (ECalBackendGroupwise *cbgw, GSList *uid_list, gchar **calobj
 
 	comp = g_object_ref ( (ECalComponent *) list->data );
 	/* convert items into components and add them to the cache */
-	for (i=0, tmp = list; tmp; tmp = g_list_next (tmp), i++) {
+	for (i = 0, tmp = list; tmp; tmp = g_list_next (tmp), i++) {
 		ECalComponent *e_cal_comp;
 		EGwItem *item;
 
@@ -1752,7 +1808,13 @@ update_from_server (ECalBackendGroupwise *cbgw, GSList *uid_list, gchar **calobj
 }
 
 static void
-e_cal_backend_groupwise_create_object (ECalBackendSync *backend, EDataCal *cal, GCancellable *cancellable, const gchar *in_calobj, gchar **uid, gchar **new_calobj, GError **error)
+e_cal_backend_groupwise_create_object (ECalBackendSync *backend,
+                                       EDataCal *cal,
+                                       GCancellable *cancellable,
+                                       const gchar *in_calobj,
+                                       gchar **uid,
+                                       gchar **new_calobj,
+                                       GError **error)
 {
 	ECalBackendGroupwise *cbgw;
 	ECalBackendGroupwisePrivate *priv;
@@ -1831,7 +1893,9 @@ e_cal_backend_groupwise_create_object (ECalBackendSync *backend, EDataCal *cal,
 }
 
 static void
-get_retract_data (ECalComponent *comp, const gchar **retract_comment, gboolean *all_instances)
+get_retract_data (ECalComponent *comp,
+                  const gchar **retract_comment,
+                  gboolean *all_instances)
 {
 	icalcomponent *icalcomp = NULL;
 	icalproperty *icalprop = NULL;
@@ -1869,8 +1933,14 @@ get_retract_data (ECalComponent *comp, const gchar **retract_comment, gboolean *
 }
 
 static void
-e_cal_backend_groupwise_modify_object (ECalBackendSync *backend, EDataCal *cal, GCancellable *cancellable, const gchar *calobj,
-				       CalObjModType mod, gchar **old_object, gchar **new_object, GError **error)
+e_cal_backend_groupwise_modify_object (ECalBackendSync *backend,
+                                       EDataCal *cal,
+                                       GCancellable *cancellable,
+                                       const gchar *calobj,
+                                       CalObjModType mod,
+                                       gchar **old_object,
+                                       gchar **new_object,
+                                       GError **error)
 {
 	ECalBackendGroupwise *cbgw;
 	ECalBackendGroupwisePrivate *priv;
@@ -2029,10 +2099,15 @@ get_gw_item_id (icalcomponent *icalcomp)
 
 /* Remove_object handler for the file backend */
 static void
-e_cal_backend_groupwise_remove_object (ECalBackendSync *backend, EDataCal *cal, GCancellable *cancellable,
-				       const gchar *uid, const gchar *rid,
-				       CalObjModType mod, gchar **old_object,
-				       gchar **object, GError **perror)
+e_cal_backend_groupwise_remove_object (ECalBackendSync *backend,
+                                       EDataCal *cal,
+                                       GCancellable *cancellable,
+                                       const gchar *uid,
+                                       const gchar *rid,
+                                       CalObjModType mod,
+                                       gchar **old_object,
+                                       gchar **object,
+                                       GError **perror)
 {
 	ECalBackendGroupwise *cbgw;
 	ECalBackendGroupwisePrivate *priv;
@@ -2163,7 +2238,8 @@ e_cal_backend_groupwise_remove_object (ECalBackendSync *backend, EDataCal *cal,
  * ../file/e-cal-backend-file.c
  */
 static void
-fetch_attachments (ECalBackendGroupwise *cbgw, ECalComponent *comp)
+fetch_attachments (ECalBackendGroupwise *cbgw,
+                   ECalComponent *comp)
 {
 	GSList *attach_list = NULL, *new_attach_list = NULL;
 	GSList *l;
@@ -2193,7 +2269,7 @@ fetch_attachments (ECalBackendGroupwise *cbgw, ECalComponent *comp)
 		g_free (filename);
 		dest_file = g_build_filename (cache_dir, new_filename, NULL);
 		g_free (new_filename);
-		fd = g_open (dest_file, O_RDWR|O_CREAT|O_TRUNC|O_BINARY, 0600);
+		fd = g_open (dest_file, O_RDWR | O_CREAT | O_TRUNC | O_BINARY, 0600);
 		if (fd == -1) {
 			/* TODO handle error conditions */
 		} else if (write (fd, g_mapped_file_get_contents (mapped_file),
@@ -2221,7 +2297,9 @@ fetch_attachments (ECalBackendGroupwise *cbgw, ECalComponent *comp)
 }
 
 static void
-change_status (ECalComponent *comp, icalparameter_partstat status, const gchar *email)
+change_status (ECalComponent *comp,
+               icalparameter_partstat status,
+               const gchar *email)
 {
 	icalproperty *prop;
 	icalparameter *param;
@@ -2268,7 +2346,10 @@ change_status (ECalComponent *comp, icalparameter_partstat status, const gchar *
 }
 
 static void
-receive_object (ECalBackendGroupwise *cbgw, EDataCal *cal, icalcomponent *icalcomp, GError **perror)
+receive_object (ECalBackendGroupwise *cbgw,
+                EDataCal *cal,
+                icalcomponent *icalcomp,
+                GError **perror)
 {
 	ECalComponent *comp, *modif_comp = NULL;
 	ECalBackendGroupwisePrivate *priv;
@@ -2397,7 +2478,11 @@ receive_object (ECalBackendGroupwise *cbgw, EDataCal *cal, icalcomponent *icalco
 
 /* Update_objects handler for the file backend. */
 static void
-e_cal_backend_groupwise_receive_objects (ECalBackendSync *backend, EDataCal *cal, GCancellable *cancellable, const gchar *calobj, GError **perror)
+e_cal_backend_groupwise_receive_objects (ECalBackendSync *backend,
+                                         EDataCal *cal,
+                                         GCancellable *cancellable,
+                                         const gchar *calobj,
+                                         GError **perror)
 {
 	ECalBackendGroupwise *cbgw;
 	ECalBackendGroupwisePrivate *priv;
@@ -2444,7 +2529,11 @@ e_cal_backend_groupwise_receive_objects (ECalBackendSync *backend, EDataCal *cal
 }
 
 static void
-send_object (ECalBackendGroupwise *cbgw, EDataCal *cal, icalcomponent *icalcomp, icalproperty_method method, GError **perror)
+send_object (ECalBackendGroupwise *cbgw,
+             EDataCal *cal,
+             icalcomponent *icalcomp,
+             icalproperty_method method,
+             GError **perror)
 {
 	ECalComponent *comp, *found_comp = NULL;
 	ECalBackendGroupwisePrivate *priv;
@@ -2497,8 +2586,13 @@ send_object (ECalBackendGroupwise *cbgw, EDataCal *cal, icalcomponent *icalcomp,
 }
 
 static void
-e_cal_backend_groupwise_send_objects (ECalBackendSync *backend, EDataCal *cal, GCancellable *cancellable, const gchar *calobj, GSList **users,
-				      gchar **modified_calobj, GError **perror)
+e_cal_backend_groupwise_send_objects (ECalBackendSync *backend,
+                                      EDataCal *cal,
+                                      GCancellable *cancellable,
+                                      const gchar *calobj,
+                                      GSList **users,
+                                      gchar **modified_calobj,
+                                      GError **perror)
 {
 	icalcomponent *icalcomp, *subcomp;
 	icalcomponent_kind kind;
@@ -2632,7 +2726,8 @@ e_cal_backend_groupwise_class_init (ECalBackendGroupwiseClass *class)
 }
 
 void
-e_cal_backend_groupwise_notify_error_code (ECalBackendGroupwise *cbgw, EGwConnectionStatus status)
+e_cal_backend_groupwise_notify_error_code (ECalBackendGroupwise *cbgw,
+                                           EGwConnectionStatus status)
 {
 	const gchar *msg;
 
